@@ -31,7 +31,8 @@ def main(ctx, config, outconfig, configalias, inputalias):
 @clk.shared_decs(clk.command_decs(hs.__version__))
 def img_cr(ctx, arg1, **kwargs):
     """get illuminance and contrast data from images
-    (assumes all images are the same size and view parameters)"""
+    (assumes all images are the same size and view parameters)
+    outputs to stdout: E_v GCR stddev absdev"""
     if kwargs['opts']:
         kwargs['opts'] = False
         clk.echo_args(arg1, **kwargs)
@@ -71,6 +72,7 @@ def img_cr(ctx, arg1, **kwargs):
               " 'x-pos', 'y-pos', 'L_s', 'Omega_s', 'Posindx', 'L_b', 'L_t', "
               "'E_vert', 'Edir', 'Max_Lum', 'Sigma', 'xdir', 'ydir', 'zdir', "
               "'Eglare_cie', 'Lveil_cie', 'teta', 'glare_zone'")
+@click.option("--headers/--no-headers", default=True)
 @clk.shared_decs(clk.command_decs(hs.__version__))
 def evalglare(ctx, arg1, **kwargs):
     """run evalglare for set of image and extract specific values"""
@@ -95,19 +97,26 @@ def evalglare(ctx, arg1, **kwargs):
                         f = sys.stdout
                     else:
                         f = open(f'{out}_{val}.txt', 'w')
-                    pline = '\t'.join([f'{i: <15}' for i in headers[val] +
-                                      kwargs[val]])
-                    print(pline, file=f)
+                    if kwargs['headers']:
+                        pline = '\t'.join([f'{i: <15}' for i in headers[val] +
+                                          kwargs[val]])
+                        print(pline, file=f)
                     for j in range(len(arg1)):
                         if val == 'srcvalues':
                             for k, src in enumerate(results[j]['srcs']):
-                                r = [imgkeys[j], k] + [src[m] for m in
-                                                       kwargs['srcvalues']]
+                                if kwargs['headers']:
+                                    r = [imgkeys[j], k] + [src[m] for m in
+                                                           kwargs['srcvalues']]
+                                else:
+                                    r = [src[m] for m in kwargs['srcvalues']]
                                 pline = '\t'.join([f'{i: <15}' for i in r])
                                 print(pline, file=f)
                         else:
-                            r = [imgkeys[j]] + [results[j][m] for m in
-                                                kwargs['values']]
+                            if kwargs['headers']:
+                                r = [imgkeys[j]] + [results[j][m] for m in
+                                                    kwargs['values']]
+                            else:
+                                r = [results[j][m] for m in kwargs['values']]
                             pline = '\t'.join([f'{i: <15}' for i in r])
                             print(pline, file=f)
                     if out is not None:
@@ -207,7 +216,12 @@ def kde_error(ctx, arg1, arg2, outpref, **kwargs):
     else:
         try:
             aS = np.loadtxt(arg1)
-            a2S = np.loadtxt(arg2)[:,kwargs['sidx']:]
+            a2S = np.loadtxt(arg2)
+            if len(aS.shape) < 2:
+                aS = aS.reshape(-1, 1)
+            if len(a2S.shape) < 2:
+                a2S = a2S.reshape(-1, 1)
+            a2S = a2S[:,kwargs['sidx']:]
             labels = aS[:,0]
             aS = aS[:,kwargs['sidx']:]
             if kwargs['baselinei'] is not None:
