@@ -46,6 +46,9 @@ def corr_header(lin=True, spearman=False, pearson=False, pvals=True, rbc=False,
     return out
 
 
+def rel_error(x, y):
+    return np.where(np.abs(y) > 0, 1 - x/y, np.where(np.abs(x) > 0, 1, 0))
+
 def corr_calc(x, y, lin=True, spearman=False, pearson=False, pvals=True,
               rbc=False, rmse=False, rrmse=False, mae=False, rmae=False,
               msd=False, rmsd=False, **kwargs):
@@ -75,18 +78,18 @@ def corr_calc(x, y, lin=True, spearman=False, pearson=False, pvals=True,
         err = np.sum(np.abs(y-x))/len(x)
         out += [err]
     if rrmse:
-        rerr = np.where(y > 0, 1 - x/y, 0)
+        rerr = rel_error(x, y)
         err = (np.sum(rerr)**2/len(x))**.5
         out += [err]
     if rmae:
-        rerr = np.where(y > 0, 1 - x/y, 0)
+        rerr = rel_error(x, y)
         err = np.sum(np.abs(rerr))/len(x)
         out += [err]
     if msd:
         err = np.sum(y-x)/len(x)
         out += [err]
     if rmsd:
-        rerr = np.where(y > 0, 1 - x/y, 0)
+        rerr = rel_error(x, y)
         err = np.sum(rerr)/len(x)
         out += [err]
     return out
