@@ -32,8 +32,7 @@ def get_omegas(image, xres, yres):
 
 def get_cos(res):
     """generate a 2D array of cos(r) values"""
-    inc = np.pi/(res-1)
-    a = np.arange(-np.pi/2, np.pi/2 + inc, inc)
+    a = np.linspace(-np.pi/2, np.pi/2, res)
     x, y = np.meshgrid(a, a, sparse=True)
     z = np.cos(np.sqrt(np.square(x) + np.square(y)))
     z[z < 0] = 0
